﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

namespace CustomComboEditorColumn
{
    public abstract class NotifyDataErrorInfoViewModelBase : ViewModelBase, INotifyDataErrorInfo
    {
        private Dictionary<String, List<String>> errors = new Dictionary<string, List<string>>();

        public void AddErrorForProperty(string propertyName, string error)
        {
            if (!errors.ContainsKey(propertyName))
                errors[propertyName] = new List<string>();

            if (!errors[propertyName].Contains(error))
            {
                errors[propertyName].Insert(0, error);
                OnNotifyPropertyChanged("HasErrors");
                RaiseErrorsChanged(propertyName);
            }
        }

        public void RemoveErrorsForProperty(string propertyName)
        {
            if (errors.ContainsKey(propertyName))
            {
                errors[propertyName].Clear();
                if (errors[propertyName].Count == 0)
                {
                    errors.Remove(propertyName);
                }
                OnNotifyPropertyChanged("HasErrors");
                RaiseErrorsChanged(propertyName);
            }
        }

        private void RaiseErrorsChanged(string propertyName)
        {
            if (ErrorsChanged != null)
                ErrorsChanged(this, new DataErrorsChangedEventArgs(propertyName));
        }


        #region INotifyDataErrorInfo member

        public IEnumerable GetErrors(string propertyName)
        {
            if (String.IsNullOrEmpty(propertyName) ||
                !errors.ContainsKey(propertyName)) return null;
            return errors[propertyName];
        }

        public bool HasErrors
        {
            get { return errors.Any(); }
        }

        public event EventHandler<DataErrorsChangedEventArgs> ErrorsChanged;

        #endregion INotifyDataErrorInfo member
    }
}
